mobdb-package: mobdb: Access the 'Mobility Database' API to Discover Transit...

mobdb-packageR Documentation

mobdb: Access the 'Mobility Database' API to Discover Transit Feeds

Description

logo

Search and access transit feed data from the 'Mobility Database' https://mobilitydatabase.org. The package wraps the 'Mobility Database' API, allowing users to discover 'GTFS' (General Transit Feed Specification) and 'GBFS' (General Bikeshare Feed Specification) feeds from agencies worldwide. Functions are designed to integrate seamlessly with packages like 'tidytransit' and 'gtfstools' for subsequent feed analysis.

Author(s)

Maintainer: Jason Adle developer@jasonadle.dev [copyright holder]

Authors:

See Also

Useful links:


mobdb documentation built on Aug. 29, 2026, 1:07 a.m.