mobdb_browse: Load the Mobility Database in browser

View source: R/utils-convenience.R

mobdb_browseR Documentation

Load the Mobility Database in browser

Description

Opens the Mobility Database in your default web browser. You'll need to log in or sign up on the website to get an API key to use this package.

Usage

mobdb_browse()

Value

Invisibly returns the URL that was opened.

Examples

## Not run: 
mobdb_browse()

## End(Not run)


mobdb documentation built on Aug. 29, 2026, 1:07 a.m.