| mobdb_cache_clear | R Documentation |
Removes cached files from the cache directory. Can remove all files or only those older than a specified number of days.
mobdb_cache_clear(older_than = NULL)
older_than |
Optional. Remove only files older than this many days. If NULL (default), removes all cached files. |
Invisibly returns NULL. Called for its side effect of removing cached files (and, if requested via older_than, only those older than the given number of days)
# Clear all cache
mobdb_cache_clear()
# Clear only files older than 7 days
mobdb_cache_clear(older_than = 7)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.