mobdb_cache_list: List cached files

View source: R/cache.R

mobdb_cache_listR Documentation

List cached files

Description

Returns a tibble with information about all cached files, including file name, size, modification time, and age.

Usage

mobdb_cache_list()

Value

Tibble with columns:

file

File name

size_mb

File size in megabytes

modified

Last modification time

age_hours

Age in hours

Examples

# List all cached files
mobdb_cache_list()

mobdb documentation built on Aug. 29, 2026, 1:07 a.m.