mobdb_has_key: Check if Mobility Database API token is configured

View source: R/utils-auth.R

mobdb_has_keyR Documentation

Check if Mobility Database API token is configured

Description

Check whether a refresh token has been set for the current session or is available in the environment.

Usage

mobdb_has_key()

Value

Logical. TRUE if a token is configured, FALSE otherwise.

Examples

# Check if API token is configured
mobdb_has_key()


mobdb documentation built on Aug. 29, 2026, 1:07 a.m.