View source: R/utils-helpers.R
| view_validation_report | R Documentation |
Opens the Mobility Database validation report for a feed or dataset in your default web browser. The report shows detailed validation results from the canonical GTFS validator.
Note: This function does not support GBFS validation reports at this time as GBFS validation reports are located at a different endpoint and have a different validation criteria.
view_validation_report(data, format = "html")
data |
One of:
|
format |
Character. Report format: "html" (default) or "json". |
Invisibly returns the URL that was opened.
get_validation_report() to extract validation data as a tibble,
filter_by_validation() to filter by quality thresholds,
mobdb_datasets() to get dataset information with validation reports
## Not run:
# View validation report for Alexandria DASH
view_validation_report("mdb-482")
# View report from dataset results
datasets <- mobdb_datasets("mdb-482")
view_validation_report(datasets)
# View JSON report instead
view_validation_report("mdb-482", format = "json")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.