| mobdb-package | R Documentation |
Search and access transit feed data from the 'Mobility Database' https://mobilitydatabase.org. The package wraps the 'Mobility Database' API, allowing users to discover 'GTFS' (General Transit Feed Specification) and 'GBFS' (General Bikeshare Feed Specification) feeds from agencies worldwide. Functions are designed to integrate seamlessly with packages like 'tidytransit' and 'gtfstools' for subsequent feed analysis.
Maintainer: Jason Adle developer@jasonadle.dev [copyright holder]
Authors:
Jason Adle developer@jasonadle.dev [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.