View source: R/utils-convenience.R
| mobdb_browse | R Documentation |
Opens the Mobility Database in your default web browser. You'll need to log in or sign up on the website to get an API key to use this package.
mobdb_browse()
Invisibly returns the URL that was opened.
## Not run:
mobdb_browse()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.