| mobdb_cache_list | R Documentation |
Returns a tibble with information about all cached files, including file name, size, modification time, and age.
mobdb_cache_list()
Tibble with columns:
file |
File name |
size_mb |
File size in megabytes |
modified |
Last modification time |
age_hours |
Age in hours |
# List all cached files
mobdb_cache_list()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.