| mobdb_has_key | R Documentation |
Check whether a refresh token has been set for the current session or is available in the environment.
mobdb_has_key()
Logical. TRUE if a token is configured, FALSE otherwise.
# Check if API token is configured
mobdb_has_key()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.